;
.include "Header.inc"       ;Label und Werte Zuweisungen
.include "Hardware.inc"     ;Hardware Label  Zuweisungen
;
;Programmstart nach RESET  ( Interrupt Vektoren Tabelle )
;
.CSEG                       ;Was ab hier folgt kommt in den FLASH-Speicher
.ORG $0000                  ;Programm beginnt an der FLASH-Adresse 0x0000..

 rjmp  _reset               ;..mit der RESET-Vectortabelle

.include "IRQm88PA.inc"     ;Restliche Interrupt Vektortabelle

.ORG INT_VECTORS_SIZE       ;Programmadresse nach den ganzen IRQ-Vektoren
;
;KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
;KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
;K Konstanten im Flash TWI_Status bzw. Rueckmeldungen
;KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
;KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
;
;Hier ist der Ablauf der zu erwartenden TWI-Rueckmeldungen ( TWSR ) eingetragen.
;Der jeweilige TWI-Status in TWSR entspricht 3x nach rechts geshiftet, der je-
;weiligen TWI-Aktion. Auf die erste Aktion ( START-BEDINGUNG ), erfolgt 
;richtigerweise die Rueckmeldung 08 >>3 = 1 im TWSR. Hierrauf folgt das Senden
;von SLA_W, was mit 18 >>3 = 3 richtigerweise im TWSR Rueckgemeldet wird usw.
;
_twi_status_check:
.DB 1,3,5,5,0,1,3,5,0,1,8,10,10,10,10,10,11,0 ;
;.DB $60,$68,$70,$78,$80,$88,$90,$90,$98,$A0,$A8,$B0,$B8,$C0,$C8,00 
;
;TWI zu sendende Datenbytes zur Initialisierung des Wii Nunchuk. 
;Diese werden von hinten angefangen zu senden. Sprich $F0 zu erst.
;
_twi_data_w:
.DB $00,$00,$FB,$55,$F0,00  ;$20,$FF,
;
;IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII
;IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII
;I Erstinitialisierungen
;IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII
;IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII
;
;Stapelzeiger initialisieren (fuer Unterprogramme und / oder Interrupts)
;
_reset:
 ldi  a,High(RAMEND)        ;RAMEND, also das Ende vom SRAM, ist in der.. 
 out  SPH,a                 ;..Definitions-datei festgelegt  
 ldi  a,Low (RAMEND)
 out  SPL,a
;
;Variablen initialisieren ( r0-r31 haben unbestimmten Inhalt )
;
 clr  flag_reg              ;Allgemeines Flaggenregister
 clr  ovf0_zaehler          ;Timer0 Overflowzaehler
 clr  key_reg               ;Tasterentprellregister
 clr  null                  ;Register mit dem Inhalt Null
 clr  twi_ablauf_nr         ;Zeiger auf die jeweilige TWI-Aktion ( START )
 clr  twi_cal_byte          ;TWI Kalibrierungsbyte 

 ldi  twi_txd,#twi_txd_anz  ;Datensendezeiger initialisieren
ldi  twi_rxd,#twi_rxd_anz  ;Datenempfangszeiger initialisieren

 ;ldi  twi_rxd,#twi_pos_anz  ;Datenempfangszeiger = Anzahl der Positionsbytes

;
;Ports Erstkonfiguration
; 
 sbi  PLA_PORT,led.pla      ;PraogrammLaufAnzeige-LED aus ( Vorerst Pullup )
 sbi  PLA_DDR, led.pla      ;PORT-Bit als Ausgang f. PLA-LED
 
 sbi  PLA_PORT,led.err      ;Error-LED ausschalten ( Vorerst Pullup )
 sbi  PLA_DDR, led.err      ;PORT-Bit als Ausgang f. Error-LED
  
 sbi  LED_PORT,led.ok       ;OK-LED ausschalten ( Vorerst Pullup )
 sbi  LED_DDR, led.ok       ;PORT-Bit als Ausgang f. OK-LED

 sbi  KEY_PORT,key.bit      ;Pullup f. Taster einschalten
;
; USART Baudrate einstellen
;
 ldi  a,#ubrr               ;f. UBRRH bei 38400 Baud mit 1,8432Hz Quarz
 clr  b                     ;f. UBBRL bei 38400 Baud mit 1,8432Hz Quarz
 sts  UBRR0H,b              ;Baudrate 38400 mit einem...
 sts  UBRR0L,a              ;...1,8432Hz Quarz
;
;USART Sendeschieberegisterinterrupt und Sender ( Transmitter ) freigeben
;
 ldi  a,1<<TXCIE0|1<<TXEN0  ;USART Sendeschieberegisterinterrupt freigeben...
 sts  UCSR0B,a              ;...und USART-Sendeeinheit einschalten
;
;USART Format ( 8,N,1 ) ist bereits nach dem Reset voreingestellt
;
;
;Timer0 Overflow Interrupt initialisieren
;
 ldi  a,1<<TOIE0            ;Timer0 Overflow Interrupt freigeben...
 sts  TIMSK0,a              ;...
 ldi  a,1<<CS02             ;Timer0 Vorteiler => 256...
 out  TCCR0B,a              ;...
;
;TWI SCL Frequenz einstellen ( ca. 102 kHz TWBR=1, mit TWBR=2 ca. 92kHz )
;
 ldi  a,#twbr               ;Ergibt zusammen mit den Vorteilerbits...
 sts  TWBR,a                ;...TWPS=0 im TWSR ca. 92 kHz

 sei                        ;Globale Interruptfreigabe im CPU-Statusregister
;
;HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH
;HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH
;H Hauptprogrammschleife
;HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH
;HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH
;
;Bei Tasterbetaetigung oder TWCR.TWEN=1 & TWIE=0
;die TWI-Sequenzen durchlaufen lassen
;
_main:
 sbrc  flag_reg,twi.err     ;TWI-Ablauf in Ordnung?..
 rjmp _twi_fail             ;..NEIN => Fehlerbehandlung
 sbrc key_reg,key.actuated  ;Taster betaetigt und entprellt?..
 rjmp _twi                  ;..JA => TWI-Sequenzen erzeugen
 lds  a,TWCR                ;TWI Controllregister laden und pruefen, ob..
 sbrc a,TWEN                ;..die TWI-ISR abgearbeitet..
 sbrc a,TWIE                ;..ist ( TWEN=1 & TWIE=0 )
 rjmp _idle                 ;TWI Abhandlung ueberspringen
 rjmp _twi                  ;JA => TWI-Sequenzen erzeugen
;
;Dem TWI-Ablauf entsprechend zur TWI-Aktion springen.
;
_twi: 
 cbr  key_reg,1<<key.actuated;Taster wieder aktivieren

 cpi  twi_ablauf_nr,#twi_ablauf_nr_anz +1;Anzahl der TWI-Aktionen zu hoch?
 brcc _twi_ablauf_nr_fail   ;..JA => Error-LED einschalten 
;
;Vorbereitung fuer den Statuscheck in der TWI-ISR 
;
 ldi  zl, LOW(_twi_status_check*2);Zur TWI-Aktion..
 ldi  zh,HIGH(_twi_status_check*2);..den zugehoerigen..
 add  zl,twi_ablauf_nr      ;..Status-Check holen und f. den Vergleich..
 adc  zh,null               ;..in der TWI-ISR ( _TWIaddr: )..
 lpm  twi_status_check,z    ;..abspeichern
;
;TWI-Ablauf. Anhand der TWI-Ablaufnummer zur jeweiligen TWI-Aktion bzw. 
;Schritt springen.
;
 ldi  zl, LOW(_twi_ablauf)  ;Den TWI-Ablaufschritt..
 ldi  zh,HIGH(_twi_ablauf)  ;..holen und..
 add  zl,twi_ablauf_nr      ;..zur entsprechenden..
 adc  zh,null               ;..TWI-Aktion..
 ijmp                       ;..springen.
;
;Wii Nunchuk initalisieren ( Initialize start Nunchuk command )
;
_twi_ablauf:
 rjmp _twi_start            ;Schritt  0 => TWI-STARTBEDINGUNG erzeugen
 rjmp _twi_sla_w            ;Schritt  1 => $A4
 rjmp _twi_data_write       ;Schritt  2 => $F0
 rjmp _twi_data_write       ;Schritt  3 => $55
 rjmp _twi_stop             ;Schritt  4 => TWI-STOPPBEDINGUNG erzeugen
 rjmp _twi_start            ;Schritt  5 => TWI-STARTBEDINGUNG erzeugen
 rjmp _twi_sla_w            ;Schritt  6 => $A4
 rjmp _twi_data_write       ;Schritt  7 => $FB
 rjmp _twi_data_write       ;Schritt  8 => $00
 rjmp _twi_stop             ;Schritt  9 => TWI-STOPPBEDINGUNG erzeugen 
;
;Wii Nunchuk fuer das Auslesen der 16 Kalibrationsbytes vorbereiten
;( Conversion command (0x20) )
;
 rjmp _twi_start            ;Schritt 10 => TWI-STARTBEDINGUNG erzeugen
 rjmp _twi_sla_w            ;Schritt 11 => $A4
 rjmp _twi_data_write_cal   ;Schritt 12 => $20
 rjmp _twi_stop             ;Schritt 13 => TWI-STOPPBEDINGUNG erzeugen 
;
;Wii Nunchuk 16 Kalibrationsbytes auslesen ( $20)
;
 rjmp _twi_start            ;Schritt 14 => TWI-STARTBEDINGUNG erzeugen
 rjmp _twi_sla_r            ;Schritt 15 => $A5 
 rjmp _twi_data_ack         ;Schritt 16 => Acknowlegde-Puls erzeugen
 rjmp _twi_data_read_cal    ;Schritt 17 => Kalibrierdaten auslesen
 rjmp _twi_data_nack        ;Schritt 18 => Not Acknowledge-Puls erzeugen u.a.
 rjmp _twi_stop             ;Schritt 19 => TWI-STOPPBEDINGUNG erzeugen 
;
;Wii Nunchuk fuer das Auslesen der 6 Positionsbytes vorbereiten
;( Conversion command (0x00) )
;
 rjmp _twi_start            ;Schritt 20 => TWI-STARTBEDINGUNG erzeugen
 rjmp _twi_sla_w            ;Schritt 21 => $A4
 rjmp _twi_data_write       ;Schritt 22 => $00
 rjmp _twi_stop             ;Schritt 23 => TWI-STOPPBEDINGUNG erzeugen 
;
;Wii Nunchuk 6 Positionsbytes auslesen
;
 rjmp _twi_start            ;Schritt 24 => TWI-STARTBEDINGUNG erzeugen
 rjmp _twi_sla_r            ;Schritt 25 => $A5
 rjmp _twi_data_ack         ;Schritt 26 => Acknowlegde-Puls erzeugen
 rjmp _twi_data_read        ;Schritt 27 => TWI-DATA lesen
 rjmp _twi_data_nack        ;Schritt 28 => Not Acknowledge-Puls erzeugen u.a.
 rjmp _twi_stop             ;Schritt 29 => TWI-STOPPBEDINGUNG erzeugen 
;
;Wii Nunchuk Werte $01-$FF an Adresse $20 schreiben
;
 rjmp _twi_start            ;Schritt 30 => TWI-STARTBEDINGUNG erzeugen
 rjmp _twi_sla_w            ;Schritt 31 => $A4
 rjmp _twi_data_write_cal   ;Schritt 32 => $20
 rjmp _twi_data_write_cal_byte   ;Schritt 33 => Werte $01-$FF schreiben
 rjmp _twi_stop             ;Schritt 34 => TWI-STOPPBEDINGUNG erzeugen 


 rjmp _twi_read_loop        ;Schritte    bis    wiederholen
;
;Die TWI-Ablaufnummer ist groesser als die Anzahl der Spruenge bei
;TWI-Ablauf (_twi_ablauf:). 
;
_twi_ablauf_nr_fail:
 cbi  PLA_PORT,led.err      ;Testweise Error-LED einschalten####################

 rjmp _idle                 ;TWI-Abhandlung ueberspringen
;
;In der TWI-ISR wurde in einer der beiden ERROR-Faelle im Flag-Register
;( flag_reg ) das TWI-ERROR-Flag (twi.err) gesetzt.
;
_twi_fail:
 cbi  PLA_PORT,led.err      ;Testweise Error-LED einschalten####################

 rjmp _idle                 ;TWI-Abhandlung ueberspringen
;
;TWI-START-Aktion ausfuehren 
;
_twi_start:
 ldi  a,#cmd_twi_start      ;START-BEDINGUNG.. 
 sts  TWCR,a	            ;..ausfuehren
 
 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;TWI-ADDRESS-WRITE-Aktion ausfuehren 
;
_twi_sla_w:
 ldi  a,#twi_sla_w          ;Slave-Write-Adresse laden..
 sts  TWDR,a                ;..und ins TWI-Data-Register schreiben 
   
 ldi  a,#cmd_twi_action     ;TWI-Aktion..
 sts  TWCR,a	            ;..ausfuehren 
 
 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;TWI-ADDRESS-READ-Aktion ausfuehren 
;
_twi_sla_r:
 ldi  a,#twi_sla_r          ;Slave-Read-Adresse laden..
 sts  TWDR,a	            ;..und ins TWI-Data-Register schreiben 
 
 ldi  a,#cmd_twi_action     ;TWI-Aktion..
 sts  TWCR,a	            ;..ausfuehren 
 
 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;TWI-DATA-Write ausfuehren
;
_twi_data_write:
 cpse twi_txd,null          ;Ende der zu schreibenden Datenbyes?
 dec  twi_txd               ;NEIN => Datensendezeiger einen weniger

 clr  zh                    ;Basisadresse der zu senden Bytes..
 ldi  zl, LOW(_twi_data_w*2);..laden und den..
 add  zl,twi_txd            ;..Datensendezeiger hinzuaddieren und aus dieser..
 lpm  twi_data,z            ;..nun gebildeten Addresse das zu sendende Byte..
 sts  TWDR,twi_data         ;..laden und ins TWI-Datenregister kopieren

 ldi  a,#cmd_twi_action     ;TWI-Aktion.. 
 sts  TWCR,a	            ;..ausfuehren 

 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;TWI-DATA-Write-Kalibrieren ausfuehren
;
_twi_data_write_cal:
 ;dec  twi_txd               ;Datensendezeiger einen weniger

 ;clr  zh                    ;Basisadresse der zu senden Bytes..
 ;ldi  zl, LOW(_twi_data_w*2);..laden und den..
 ;add  zl,twi_txd            ;..Datensendezeiger hinzuaddieren und aus dieser..
; lpm  twi_data,z            ;..nun gebildeten Addresse das zu sendende Byte..
 ;sts  TWDR,twi_data         ;..laden und ins TWI-Datenregister kopieren

 ldi  a,$24                 ;Speicheradresse $24 laden..
 cpse twi_rxd,null
 ldi  a,$20                 ;Speicheradresse $20 laden..

 sts  TWDR,a                ;..und ins TWI Data-Register kopieren

 ldi  a,#cmd_twi_action     ;TWI-Aktion.. 
 sts  TWCR,a	            ;..ausfuehren 

 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;TWI-DATA-Write Bytes schreiben
;
_twi_data_write_cal_byte:
 inc  twi_cal_byte          ;Kalibrierwert inkrementieren..
 inc  twi_cal_byte          ;Kalibrierwert inkrementieren..
 inc  twi_cal_byte          ;Kalibrierwert inkrementieren..
 inc  twi_cal_byte          ;Kalibrierwert inkrementieren..
 sts  TWDR,twi_cal_byte     ;..und ins TWI-Datenregister kopieren

 ldi  a,#cmd_twi_action     ;TWI-Aktion.. 
 sts  TWCR,a	            ;..ausfuehren 

 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;Acknowledge : Zum Lesen der Daten mit anschliessendem erzeugen von ACK 
; 
_twi_data_ack: 
 ldi  a,#cmd_twi_ack        ;Acknowlegde-Puls..
 sts  TWCR,a                ;..als Abschluss generieren

 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;TWI 16 Wii Nunchuk Kalibrierbytes lesen und im SRAM speichern
; 
_twi_data_read_cal:
 dec  twi_rxd               ;Datenempfangszeiger einen weniger
 
 ldi  zh,HIGH(_twi_data_r)  ;..SRAM-Basisadresse.. 
 ldi  zl,LOW (_twi_data_r)  ;..laden..
 add  zl,twi_rxd            ;..und Datenempfangszeiger..
 adc  zh,null               ;..hinzuaddieren. Somit aktuelle Adresse erzeugen

 lds  twi_data,TWDR         ;TWI-Datenbyte einlesen..
 st   z,twi_data            ;..und ins SRAM kopieren

 rcall _warte_udre          ;TESTZWECKE ########################################
 ld   twi_data,z            ;TESTZWECKE ########################################
 sts  UDR0,twi_data         ;TESTZWECKE ########################################

 cpi  twi_rxd,7             ;15 Bytes empfangen mit abschliessendem ACK fertig?
 breq _twi_nack             ;JA => springen zu 16tes Byte lesen mit NACK am Ende

 dec  twi_ablauf_nr         ;Zurueck zu " Acknowlegde-Puls erzeugen "
 rjmp _idle                 ;Weiter im Programmlauf
;
;TWI 6 Wii Nunchuk Positionsbytes lesen und im SRAM speichern
; 
_twi_data_read:
 dec  twi_rxd               ;Datenempfangszeiger einen weniger
 
 ldi  zh,HIGH(_twi_data_r)  ;..SRAM-Basisadresse.. 
 ldi  zl,LOW (_twi_data_r)  ;..laden..
 add  zl,twi_rxd            ;..und Datenempfangszeiger..
 adc  zh,null               ;..hinzuaddieren. Somit aktuelle Adresse erzeugen

 lds  twi_data,TWDR         ;TWI-Datenbyte einlesen..
 st   z,twi_data            ;..und ins SRAM kopieren

 rcall _warte_udre          ;TESTZWECKE ########################################
 ld   twi_data,z            ;TESTZWECKE ########################################
 sts  UDR0,twi_data         ;TESTZWECKE ########################################

 cpi  twi_rxd,1             ;Daten empfangen mit abschliessendem ACK fertig?
 breq _twi_nack             ;JA => springen zu Daten lesen mit NACK am Ende

 dec  twi_ablauf_nr         ;Zurueck zu " Acknowlegde-Puls erzeugen "
 rjmp _idle                 ;Weiter im Programmlauf
;
;Dem letzten eingelesenem Byte ein Not Acklowlegde verpassen
;
_twi_nack:
 ldi  a,#cmd_twi_action     ;TWI-Aktion ausfuehren und somit ein..
 sts  TWCR,a	            ;..NOT Acknowledge erzeugen 

 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;Nun das letzte Byte mit dem abschliessendem NACK einlesen
;
_twi_data_nack: 
 dec  twi_rxd               ;Datenempfangszeiger einen weniger
 
 ldi  zh,HIGH(_twi_data_r)  ;..SRAM-Basisadresse.. 
 ldi  zl,LOW (_twi_data_r)  ;..laden..
 add  zl,twi_rxd            ;..und Datenempfangszeiger..
 adc  zh,null               ;..hinzuaddieren
  
 lds  twi_data,TWDR         ;TWI-Datenbyte einlesen..
 st   z,twi_data            ;..und ins SRAM kopieren

 rcall _warte_udre          ;TESTZWECKE ########################################
 ld   twi_data,z            ;TESTZWECKE ########################################
 sts  UDR0,twi_data         ;TESTZWECKE ########################################

 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;TWI-STOP-Aktion ausfuehren.
;  
_twi_stop:
 ldi  a,#cmd_twi_stop       ;STOP-BEDINGUNG..
 sts  TWCR,a                ;..ausfuehren

 sbr  key_reg,1<<key.actuated;Taster als entprellt & gedrueckt simulieren#######

 rjmp _twi_takten           ;Den TWI-Ablauf weitertakten
;
;TWI-Empfangsdaten lesen als Dauerschleife
;
_twi_read_loop:
 ldi  twi_ablauf_nr,9;20       ;TWI-Sequenz Daten lesen ( wird im weiteren..
                            ;..Programmablauf bei _twi_takten: inkrementiert )

 ldi   twi_rxd,#twi_rxd_anz ;Datenempfangszeiger erneut initialisieren

 ;ldi   twi_txd,#twi_txd_anz ;Datensendezeiger erneut initialisieren

 ;inc  twi_txd               ;Datensendezeiger auf das letztes Byte zeigen lassen
 
 ;sbr  key_reg,1<<key.actuated;Taster als gedrueckt & entprellt simulieren#######
;
;TWI-Ablauf weitertakten
;
_twi_takten:
 inc  twi_ablauf_nr         ;TWI-Ablauf einen Schritt weiterschalten 
;
;ProgrammLaufAnzeige (PLA) in Gang halten
;
_idle: 
 sbr  flag_reg,1<<pla.flg   ;Programmlaufanzeige-Flag quitieren
 
 rjmp _main                 ;Sprung zum Anfang des Hauptprogramms ( Mainloop )
; 
;UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU
;UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU
;U Beginn der verwendeten Unterprogramme
;UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU
;UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU
;
.include "UP.inc";Unterprogramme
;
;QQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQ
;QQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQ
;Q Beginn der verwendeten Interrupt Service Routinen ( ISR )
;QQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQ
;QQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQ
;
.include "ISR.inc";Interrupt Service Routinen
;
;DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD
;DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD
;D Daten im SRAM ablegen
;DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD
;DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD
;
.DSEG

_twi_data_r:
.BYTE #twi_rxd_anz          ;Eingelesenen Wii Nunchuk Bytes ab hier ablegen
 
.EXIT                       ;Ende des Quelltextes
